@@ -99,9 +99,9 @@ pub fn setup_scripts(name: &str, version: &Version, lib_path: &Path, entry_pt_pa
     let mut dist_info_path = lib_path.join(format!("{}-{}.dist-info", name, version.to_string()));
     // If we can't find the dist_info path, it may be due to it not using a full 3-digit semver format.
     // todo: Dry from dep_resolution, release check.
-    if !dist_info_path.exists() && version.patch == 0 {
+    if !dist_info_path.exists() && (version.patch == Some(0) || version.patch == None) {
         dist_info_path = lib_path.join(format!("{}-{}.dist-info", name, version.to_string_med()));
-        if !dist_info_path.exists() && version.minor == 0 {
+        if !dist_info_path.exists() && (version.minor == Some(0) || version.minor == None) {
             dist_info_path =
                 lib_path.join(format!("{}-{}.dist-info", name, version.to_string_short()));
         }
@@ -160,7 +160,7 @@ pub fn setup_scripts(name: &str, version: &Version, lib_path: &Path, entry_pt_pa
 
 /// Download and install a package. For wheels, we can just extract the contents into
 /// the lib folder.  For source dists, make a wheel first.
-#[allow(clippy::clippy::too_many_arguments)]
+#[allow(clippy::too_many_arguments)]
 pub fn download_and_install_package(
     name: &str,
     version: &Version,
@@ -249,6 +249,10 @@ pub fn download_and_install_package(
             let tar = GzDecoder::new(&archive_file);
             let mut archive = Archive::new(tar);
 
+            // Some python archives don't have file create times set which
+            // breaks wheel builds. Don't preserve mtime fixes this.
+            archive.set_preserve_mtime(false);
+
             // We iterate over and copy entries instead of running `Archive.unpack`, since
             // symlinks in the archive may cause the unpack to break. If this happens, we want
             // to continue unpacking the other files.
@@ -502,13 +506,13 @@ pub fn uninstall(name_ins: &str, vers_ins: &Version, lib_path: &Path) {
     let mut dist_info_path =
         lib_path.join(format!("{}-{}.dist-info", name_ins, vers_ins.to_string()));
     // todo: DRY
-    if !dist_info_path.exists() && vers_ins.patch == 0 {
+    if !dist_info_path.exists() && (vers_ins.patch == Some(0) || vers_ins.patch == None) {
         dist_info_path = lib_path.join(format!(
             "{}-{}.dist-info",
             name_ins,
             vers_ins.to_string_med()
         ));
-        if !dist_info_path.exists() && vers_ins.minor == 0 {
+        if !dist_info_path.exists() && (vers_ins.minor == Some(0) || vers_ins.minor == None) {
             dist_info_path = lib_path.join(format!(
                 "{}-{}.dist-info",
                 name_ins,
