@@ -1,6 +1,10 @@
 #![allow(clippy::non_ascii_literal)]
 
-use crate::dep_types::{Constraint, Lock, LockPackage, Package, Rename, Req, ReqType, Version};
+#[mockall_double::double]
+use crate::dep_resolution::res;
+use crate::dep_types::{
+    Constraint, Extras, Lock, LockPackage, Package, Rename, Req, ReqType, Version,
+};
 use crate::util::{abort, Os};
 
 use regex::Regex;
@@ -314,10 +318,9 @@ impl Config {
                         git = Some(repo);
                     }
                     if let Some(v) = subdata.python {
-                        python_version = Some(
-                            Constraint::from_str(&v)
-                                .expect("Problem parsing python version in dependency"),
-                        );
+                        let pv = Constraint::from_str(&v)
+                            .expect("Problem parsing python version in dependency");
+                        python_version = Some(vec![pv]);
                     }
                 }
             }
@@ -452,10 +455,9 @@ impl Config {
                                 extras = Some(ex);
                             }
                             if let Some(v) = subdata.python {
-                                python_version = Some(
-                                    Constraint::from_str(&v)
-                                        .expect("Problem parsing python version in dependency"),
-                                );
+                                let pv = Constraint::from_str(&v)
+                                    .expect("Problem parsing python version in dependency");
+                                python_version = Some(vec![pv]);
                             }
                             // todo repository etc
                         }
@@ -816,8 +818,8 @@ fn sync_deps(
     }
 
     for ((name, version), rename) in &to_install {
-        let data = dep_resolution::get_warehouse_release(name, version)
-            .expect("Problem getting warehouse data");
+        let data =
+            res::get_warehouse_release(name, version).expect("Problem getting warehouse data");
 
         let (best_release, package_type) =
             util::find_best_release(&data, name, version, os, python_vers);
@@ -1006,7 +1008,7 @@ fn run_script(
     script_env_path: &Path,
     dep_cache_path: &Path,
     os: util::Os,
-    args: &Vec<String>,
+    args: &[String],
     pyflow_dir: &Path,
 ) {
     #[cfg(debug_assertions)]
@@ -1085,8 +1087,15 @@ fn run_script(
                     Version::from_str(&lp.version).expect("Problem getting version"),
                 )
             } else {
-                let vinfo = dep_resolution::get_version_info(name)
-                    .unwrap_or_else(|_| panic!("Problem getting version info for {}", &name));
+                let vinfo = res::get_version_info(
+                    name,
+                    Some(Req::new_with_extras(
+                        name.to_string(),
+                        vec![Constraint::new_any()],
+                        Extras::new_py(Constraint::new(ReqType::Exact, py_vers.clone())),
+                    )),
+                )
+                .unwrap_or_else(|_| panic!("Problem getting version info for {}", &name));
                 (vinfo.0, vinfo.1)
             };
 
@@ -1112,7 +1121,7 @@ fn run_script(
 
 /// Function used by `Install` and `Uninstall` subcommands to syn dependencies with
 /// the config and lock files.
-#[allow(clippy::clippy::too_many_arguments)]
+#[allow(clippy::too_many_arguments)]
 fn sync(
     paths: &util::Paths,
     lockpacks: &[LockPackage],
@@ -1170,7 +1179,7 @@ fn sync(
         combined_reqs.push(dev_req);
     }
 
-    let resolved = if let Ok(r) = dep_resolution::resolve(&combined_reqs, &locked, os, py_vers) {
+    let resolved = if let Ok(r) = res::resolve(&combined_reqs, &locked, os, py_vers) {
         r
     } else {
         abort("Problem resolving dependencies");
@@ -1463,10 +1472,7 @@ fn main() {
             cfg.py_version = Some(specified.clone());
             files::change_py_vers(&PathBuf::from(&cfg_path), &specified);
             util::print_color(
-                &format!(
-                    "Switched to Python version {}.{}",
-                    &specified.major, &specified.minor
-                ),
+                &format!("Switched to Python version {}", specified.to_string()),
                 Color::Green,
             );
             // Don't return; now that we've changed the cfg version, let's run the normal flow.
